@@ -1,6 +1,8 @@
 # this file is written in UTF-8 encoding
 
 
+if (requireNamespace("testthat", quietly = TRUE)) {
+if (requireNamespace("pdftools", quietly = TRUE)) {
 context('fill pdf internals')
 
 
@@ -40,3 +42,6 @@ test_that('fdf manipulation',{
 
 
 })
+
+  }
+}
